% SOFC dynamic model Parameter for M6
%=========================================================================%
% P   ->  [atm]
% Q   ->  [mol/s]
% D   ->  [m2/s]
%=========================================================================%

%=========================================================================%
% Electrochemical Parameter
%=========================================================================%
Ea      = 1.1e5;        % [J/mol]       Activity energy of anode reaction
Ec      = 1.2e5;        % [J/mol]       Activity energy of cathode reaction
F       = 96487;        %               Faraday constant

%=========================================================================%
% Electrical Parameter
%=========================================================================%
Ro      = 0.01;         % [Ohm]         Pure ohmic resistance
% Rct     = 0.9;          % [Ohm]         Charge transfer resistance    
C       = 300e-6;       % [F]           Charge transfer capacitance

%=========================================================================%
% Mechanical Parameter
%=========================================================================%
La      = 0.1e-3;       % [m]           Thickness of anode
Lc      = 2.21e-3;      % [m]           Thickness of cathode
Le      = 0.04e-3;      % [m]           Thickness of electrolyte

A       = 1e-4;         % [m^2]         Cell effective area

r3      = 11e-3;        % [m]           Radius of outer cell tube
r2      = 8.66e-3;      % [m]           Radius of inner cell tube
r1      = 6e-3;         % [m]           Radius of outer inject tube
r0      = 5e-3;         % [m]           Radius of inner inject tube

Aa      = r3^2*(4-pi);  % [m^2]         Fuel channel cross area
Ac     = pi*(r2^2-r1^2);% [m^2]         Air channel cross area
At      = pi*r0^2;      % [m^2]         Injection channel cross area

dVa    = Aa*A/(2*pi*r3);% [m^3]         Fuel channel element volume
dVc    = Ac*A/(2*pi*r3);% [m^3]         Air channel element volume
dVt    = At*A/(2*pi*r3);% [m^3]         Injection channel element volume

%=========================================================================%
% Flow mechanics Parameter
%=========================================================================%
D_a     = 0.273*2*r3;   % [m]           Hydraulic diameter of fuel side flow
D_c     = 2*(r2-r1);    % [m]           Hydraulic diameter of air side flow
D_t     = 2*r0;         % [m]           Hydraulic diameter of inject tube

%=========================================================================%
% Thermal dynamics Parameter
%=========================================================================%
Ems2    = 0.9;          %               Emissivity of cell inner surface
Ems1    = 0.4;          %               Emissivity of inject tube outer surface
F21     = 0.69;         %               View facter
delta   = 5.67e-8;      % [W/(M^2 K^4)] Stefan-Boltzmann constant
Rouc    = 4592;         % [kg/m^3]      Density of entire cell
Cpc     = 740;          % [J/(kg.K)]    Entire specific heat of cell
Rout    = 3900;         % [kg/m^3]      Density of injection tube
Cpt     = 1217.7;       % [J/(kg.K)]    Specific heat of injection tube

%=========================================================================%
% Universal Gas Constant
%=========================================================================%
R       = 8.314/101325; %               When unites at [atm] and [K]

%=========================================================================%
% Other Parameters
%=========================================================================%
K       = 10;           %               Approximation constant
T_tube  = 1123;         % [K]           Temperature of injection tube

x_ini=[ 
        8.4243e-01   1.0887e-06  -2.3809e-17   5.4433e-07  -1.2938e-17  ...
       -1.0887e-06   2.0487e-17   2.5091e-01  -7.3746e-14   1.5583e-01  ...
       -6.3027e-13   2.8338e-01  -3.0365e-13   4.0100e+01   1.0808e+03  ...
        1.0930e+03   8.2491e+02   1.1036e+03   1.1039e+03   3.7793e-07  ...
        6.2663e-07   5.5964e-07   1.2937e-07   4.9439e-07   1.5458e-06  ...
        4.1081e-07   9.4325e-01   7.7901e+00
        ]';